"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const debug_1 = __importDefault(require("debug"));
const lodash_1 = require("lodash");
const strategy_1 = require("./strategy");
exports.OAuthStrategy = strategy_1.OAuthStrategy;
const express_1 = __importDefault(require("./express"));
const utils_1 = require("./utils");
const debug = debug_1.default('@feathersjs/authentication-oauth');
exports.setup = (options) => (app) => {
    const path = options.authService;
    const service = app.service(path);
    if (!service) {
        throw new Error(`'${path}' authentication service must exist before registering @feathersjs/authentication-oauth`);
    }
    const { oauth } = service.configuration;
    if (!oauth) {
        debug(`No oauth configuration found at '${path}'. Skipping oAuth setup.`);
        return;
    }
    const { strategyNames } = service;
    const grant = lodash_1.merge({
        defaults: {
            host: `${app.get('host')}:${app.get('port')}`,
            path: '/auth',
            protocol: app.get('env') === 'production' ? 'https' : 'http',
            transport: 'session'
        }
    }, lodash_1.omit(oauth, 'redirect'));
    lodash_1.each(grant, (value, key) => {
        if (key !== 'defaults') {
            value.callback = value.callback || `/auth/${key}/authenticate`;
            if (!strategyNames.includes(key)) {
                debug(`Registering oAuth default strategy for '${key}'`);
                service.register(key, new strategy_1.OAuthStrategy());
            }
        }
    });
    app.set('grant', grant);
};
exports.express = (settings = {}) => (app) => {
    const options = utils_1.getDefaultSettings(app, settings);
    app.configure(exports.setup(options));
    app.configure(express_1.default(options));
};
//# sourceMappingURL=index.js.map